@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: wrap.cc 448 2007-10-03 09:52:10Z murrayc $ */
+/* $Id: wrap.cc 658 2008-04-24 15:53:38Z jjongsma $ */
 
 /* wrap.cc
  *
@@ -187,7 +187,7 @@ ObjectBase* wrap_auto(GObject* object, bool take_copy)
 
     if(!pCppObject)
     {
-      g_warning("failed to wrap type of '%s'", G_OBJECT_TYPE_NAME(object));
+      g_warning("Failed to wrap object of type '%s'. Hint: this error is commonly caused by failing to call a library init() function.", G_OBJECT_TYPE_NAME(object));
       return 0;
     }
   }
